package org.opennms.netmgt.jasper.compiler;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;

import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
import net.sf.jasperreports.engine.util.JRProperties;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;
import org.opennms.netmgt.jasper.compiler.JasperCompilerApplication;
import org.xml.sax.SAXException;

public class SubreportExpressionTest {
    
    private JasperCompilerApplication m_app = new JasperCompilerApplication();
    
    @Before
    public void setup() {
        JRProperties.setProperty(JRQueryExecuterFactory.QUERY_EXECUTER_FACTORY_PREFIX + "jrobin", "org.opennms.netmgt.jasper.jrobin.JRobinQueryExecutorFactory");
        JRProperties.setProperty(JRQueryExecuterFactory.QUERY_EXECUTER_FACTORY_PREFIX + "resourceQuery", "org.opennms.netmgt.jasper.resource.ResourceQueryExecuterFactory");
    }
    
    @Test
    public void testParseSubreportExpression() {
        String expression = "$P{SUBREPORT_DIR} + \"TotalBytesTransferredByInterface_subreport1.jasper\"";
        
        assertEquals("TotalBytesTransferredByInterface_subreport1.jasper", m_app.getSubreportFilename(expression));
        assertEquals("SUBREPORT_DIR", m_app.getSubreportDirParameter(expression));
    }
    
    @Test
    public void testCompileReportWithSubReports()  {
        try {
            
            m_app.compileReport("src/main/reports/", "NTRS_Report_Layer7.jrxml");
            
            File reportFile = new File("target/reports/NTRS_Report_Layer7.jrxml");
            assertTrue(reportFile.exists());
            
        }  catch (IOException e) {
            e.printStackTrace();
        }

    }
    
    @Test
    public void testParsePomProfiles() throws ParserConfigurationException, SAXException, IOException {
        m_app.parsePomProfiles("pom.xml");
    }
    
    @Test
    public void testSaxParserXML() throws ParserConfigurationException, SAXException, IOException {
        //TODO: create a parser to load a report and filter then compile it to a file.
        File file = new File("src/test/resources/FilterFile.xml");
        String fileStr = FileUtils.readFileToString(file);
        
        fileStr = fileStr.replaceAll("\\$\\{installDir\\}", "/opt/opennms");
        
        File output = new File("target/FilterFile_output.xml");
        FileUtils.writeStringToFile(output, fileStr, "UTF-8");
        
    }

}
